@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# Copyright (C) 2009-2021 The Perl Foundation
+# Copyright (C) 2009-2022 The Perl Foundation
 
 use 5.10.1;
 use strict;
@@ -12,16 +12,19 @@ use FindBin;
 
 
 BEGIN {
-    # Download / Update submodules
-    my $set_config = !qx{git config rakudo.initialized};
-    if ( !-e '3rdparty/nqp-configure/LICENSE' ) {
-        my $code = system($^X, 'tools/build/update-submodules.pl', Cwd::cwd(), @ARGV);
-        exit 1 if $code >> 8 != 0;
-        $set_config = 1;
-    }
-    if ($set_config) {
-        system("git config submodule.recurse true");
-        system("git config rakudo.initialized 1");
+    # The .git folder is typically missing in release archives.
+    if (-e '.git') {
+        # Download / Update submodules
+        my $set_config = !qx{git config rakudo.initialized};
+        if ( !-e '3rdparty/nqp-configure/LICENSE' ) {
+            my $code = system($^X, 'tools/build/update-submodules.pl', Cwd::cwd(), @ARGV);
+            exit 1 if $code;
+            $set_config = 1;
+        }
+        if ($set_config) {
+            system("git config submodule.recurse true");
+            system("git config rakudo.initialized 1");
+        }
     }
 }
 
